#ifndef PROJECT_H
#define PROJECT_H

#include <string>
#include <list>

#include "DOFVector.h"
#include "SystemVector.h"

using namespace AMDiS;
using namespace std;

struct SolutionInformation {
  SystemVector* sysVec;
  DOFVector< double >* dofVec;
  SolutionInformation():
    sysVec(NULL),
    dofVec(NULL)
  {}

};

class Project {
  public:
    virtual void create(std::string& ) = 0;
    virtual int solve(SolutionInformation&) = 0;

};

class ProjectInfo {
  string initfilename;
  Project* project;
  string outputfilename;

  public:
    ProjectInfo(Project* project, 
	string initfilename,
	string outputfilename):
      initfilename(initfilename),
      project(project),
      outputfilename(outputfilename) {}

  void create() {
    assert(initfilename.length() > 0);
    assert(project!=NULL);
    project->create(initfilename);
  }

  int solve(SolutionInformation& info) {
    assert(project!=NULL);
    return project->solve(info);
  }

  inline string getFilename() const { 
    return outputfilename;
  }
};

#endif
